/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id ResourceMonitorImpl.java $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.plan.monitor.impl;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.ow2.util.plan.bindings.deploymentplan.DeploymentPlanFragment;
import org.ow2.util.plan.fetcher.api.IResourceFetcher;
import org.ow2.util.plan.fetcher.api.exceptions.FetcherException;
import org.ow2.util.plan.monitor.api.IResourceMonitor;

/**
 * Implementation for the resource monitor.
 * @author Mickaël LEDUQUE
 */
public class ResourceMonitorImpl implements IResourceMonitor {

    /**
     * The logger.
     */
    private Log logger = LogFactory.getLog(ResourceMonitorImpl.class);

    /**
     * The monitored resources.
     */
    private List<IResourceFetcher> monitoredResources = new ArrayList<IResourceFetcher>();

    /**
     * {@inheritDoc}
     */
    public void addMonitoredResource(IResourceFetcher resourceFetcher) {
        monitoredResources.add(resourceFetcher);
    }

    /**
     * {@inheritDoc}
     */
    public void removeMonitoredResource(DeploymentPlanFragment deployment) {
        for (IResourceFetcher fetcher : monitoredResources) {
            if ((fetcher.getDeployment()).equals(deployment)) {
                monitoredResources.remove(fetcher);
                return;
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    public List<IResourceFetcher> getChangedResources() {
        List<IResourceFetcher> result = new ArrayList<IResourceFetcher>();

        for (IResourceFetcher fetcher : this.monitoredResources) {
            try {
                if (fetcher.hasChanged()) {
                    result.add(fetcher);
                }
            } catch (FetcherException e) {
                logger.warn("Exception while checking resource {0} ; exception: {1}",
                        fetcher.getDeployment(), e);
            }
        }

        return result;
    }

    /**
     * {@inheritDoc}
     */
    public Integer getMonitoredResourcesCount() {
        return this.monitoredResources.size();
    }

    /**
     * {@inheritDoc}
     */
    public List<String> getMonitoredResourcesDescriptions() {
        List<String> result = new ArrayList<String>();
        for (IResourceFetcher fetcher : monitoredResources) {
            result.add(fetcher.toString());
        }
        return result;
    }

    /**
     * {@inheritDoc}
     */
    public void removeMonitoredResource(IResourceFetcher resourceFetcher) {
        monitoredResources.remove(resourceFetcher);
    }

}
